@@ -1,3 +1,6 @@
+/* global postL10n, ajaxurl, wpAjax, setPostThumbnailL10n, postboxes, pagenow, tinymce, alert, deleteUserSetting, getUserSetting, setUserSetting */
+/* global theList:true, theExtraList:true, autosave:true */
+
 var tagBox, commentsBox, editPermalink, makeSlugeditClickable, WPSetThumbnailHTML, WPSetThumbnailID, WPRemoveThumbnail, wptitlehint;
 
 // return an array with any duplicate, whitespace or values removed
@@ -81,11 +84,11 @@ tagBox = {
 	},
 
 	flushTags : function(el, a, f) {
-		a = a || false;
-		var tags = $('.the-tags', el),
+		var tagsval, newtags, text,
+			tags = $('.the-tags', el),
 			newtag = $('input.newtag', el),
-			comma = postL10n.comma,
-			newtags, text;
+			comma = postL10n.comma;
+		a = a || false;
 
 		text = a ? $(a).text() : newtag.val();
 		tagsval = tags.val();
@@ -108,7 +111,7 @@ tagBox = {
 		var tax = id.substr(id.indexOf('-')+1);
 
 		$.post(ajaxurl, {'action':'get-tagcloud', 'tax':tax}, function(r, stat) {
-			if ( 0 == r || 'success' != stat )
+			if ( 0 === r || 'success' != stat )
 				r = wpAjax.broken;
 
 			r = $('<p id="tagcloud-'+tax+'" class="the-tagcloud">'+r+'</p>');
@@ -137,7 +140,7 @@ tagBox = {
 		});
 
 		$('input.newtag', ajaxtag).blur(function() {
-			if ( this.value == '' )
+			if ( '' === this.value )
 				$(this).parent().siblings('.taghint').css('visibility', '');
 		}).focus(function(){
 			$(this).parent().siblings('.taghint').css('visibility', 'hidden');
@@ -206,7 +209,7 @@ commentsBox = {
 					$('#the-comment-list').append( r.responses[0].data );
 
 					theList = theExtraList = null;
-					$("a[className*=':']").unbind();
+					$( 'a[className*=\':\']' ).unbind();
 
 					if ( commentsBox.st > commentsBox.total )
 						$('#show-comments').hide();
@@ -240,7 +243,7 @@ WPSetThumbnailID = function(id){
 
 WPRemoveThumbnail = function(nonce){
 	$.post(ajaxurl, {
-		action:"set-post-thumbnail", post_id: $('#post_ID').val(), thumbnail_id: -1, _ajax_nonce: nonce, cookie: encodeURIComponent(document.cookie)
+		action: 'set-post-thumbnail', post_id: $( '#post_ID' ).val(), thumbnail_id: -1, _ajax_nonce: nonce, cookie: encodeURIComponent( document.cookie )
 	}, function(str){
 		if ( str == '0' ) {
 			alert( setPostThumbnailL10n.error );
@@ -259,10 +262,10 @@ $(document).on( 'heartbeat-send.refresh-lock', function( e, data ) {
 	if ( ! post_id || ! $('#post-lock-dialog').length )
 		return;
 
-	send['post_id'] = post_id;
+	send.post_id = post_id;
 
 	if ( lock )
-		send['lock'] = lock;
+		send.lock = lock;
 
 	data['wp-refresh-post-lock'] = send;
 });
@@ -351,7 +354,8 @@ $(document).on( 'heartbeat-tick.refresh-lock', function( e, data ) {
 }(jQuery));
 
 jQuery(document).ready( function($) {
-	var stamp, visibility, sticky = '', last = 0, co = $('#content');
+	var stamp, visibility, updateVisibility, updateText,
+		sticky = '', last = 0, co = $('#content');
 
 	postboxes.add_postbox_toggles(pagenow);
 
@@ -371,6 +375,11 @@ jQuery(document).ready( function($) {
 		}
 	}).filter(':visible').find('.wp-tab-first').focus();
 
+	// Set the heartbeat interval to 15 sec. if post lock dialogs are enabled
+	if ( typeof wp !== 'undefined' && wp.heartbeat && $('#post-lock-dialog').length ) {
+		wp.heartbeat.interval( 15 );
+	}
+
 	// multi-taxonomies
 	if ( $('#tagsdiv-post_tag').length ) {
 		tagBox.init();
@@ -401,17 +410,17 @@ jQuery(document).ready( function($) {
 			$('#' + taxonomy + '-tabs').siblings('.tabs-panel').hide();
 			$(t).show();
 			if ( '#' + taxonomy + '-all' == t )
-				deleteUserSetting(settingName);
+				deleteUserSetting( settingName );
 			else
-				setUserSetting(settingName, 'pop');
+				setUserSetting( settingName, 'pop' );
 			return false;
 		});
 
-		if ( getUserSetting(settingName) )
+		if ( getUserSetting( settingName ) )
 			$('a[href="#' + taxonomy + '-pop"]', '#' + taxonomy + '-tabs').click();
 
 		// Ajax Cat
-		$('#new' + taxonomy).one( 'focus', function() { $(this).val( '' ).removeClass( 'form-input-tip' ) } );
+		$( '#new' + taxonomy ).one( 'focus', function() { $( this ).val( '' ).removeClass( 'form-input-tip' ); } );
 
 		$('#new' + taxonomy).keypress( function(event){
 			if( 13 === event.keyCode ) {
@@ -463,7 +472,7 @@ jQuery(document).ready( function($) {
 
 	// Custom Fields
 	if ( $('#postcustom').length ) {
-		$('#the-list').wpList( { addAfter: function( xml, s ) {
+		$( '#the-list' ).wpList( { addAfter: function() {
 			$('table#list-table').show();
 		}, addBefore: function( s ) {
 			s.data += '&post_id=' + $('#post_ID').val();
@@ -477,7 +486,7 @@ jQuery(document).ready( function($) {
 		stamp = $('#timestamp').html();
 		visibility = $('#post-visibility-display').html();
 
-		function updateVisibility() {
+		updateVisibility = function() {
 			var pvSelect = $('#post-visibility-select');
 			if ( $('input:radio:checked', pvSelect).val() != 'public' ) {
 				$('#sticky').prop('checked', false);
@@ -490,9 +499,9 @@ jQuery(document).ready( function($) {
 			} else {
 				$('#password-span').show();
 			}
-		}
+		};
 
-		function updateText() {
+		updateText = function() {
 
 			if ( ! $('#timestampdiv').length )
 				return true;
@@ -531,14 +540,14 @@ jQuery(document).ready( function($) {
 						.replace( '%2$s', jj )
 						.replace( '%3$s', aa )
 						.replace( '%4$s', hh )
-						.replace( '%5$s', mn )
-					+ '</b> '
+						.replace( '%5$s', mn ) +
+						'</b> '
 				);
 			}
 
 			if ( $('input:radio:checked', '#post-visibility-select').val() == 'private' ) {
 				$('#publish').val( postL10n.update );
-				if ( optPublish.length == 0 ) {
+				if ( 0 === optPublish.length ) {
 					postStatus.append('<option value="publish">' + postL10n.privatelyPublished + '</option>');
 				} else {
 					optPublish.html( postL10n.privatelyPublished );
@@ -569,10 +578,10 @@ jQuery(document).ready( function($) {
 				}
 			}
 			return true;
-		}
+		};
 
 		$('.edit-visibility', '#visibility').click(function () {
-			if ($('#post-visibility-select').is(":hidden")) {
+			if ( $( '#post-visibility-select' ).is( ':hidden' ) ) {
 				updateVisibility();
 				$('#post-visibility-select').slideDown('fast');
 				$(this).hide();
@@ -602,7 +611,7 @@ jQuery(document).ready( function($) {
 				$('#sticky').prop('checked', false);
 			} // WEAPON LOCKED
 
-			if ( true == $('#sticky').prop('checked') ) {
+			if ( $('#sticky').prop('checked') ) {
 				sticky = 'Sticky';
 			} else {
 				sticky = '';
@@ -617,7 +626,7 @@ jQuery(document).ready( function($) {
 		});
 
 		$('#timestampdiv').siblings('a.edit-timestamp').click(function() {
-			if ($('#timestampdiv').is(":hidden")) {
+			if ( $( '#timestampdiv' ).is( ':hidden' ) ) {
 				$('#timestampdiv').slideDown('fast');
 				$('#mm').focus();
 				$(this).hide();
@@ -656,7 +665,7 @@ jQuery(document).ready( function($) {
 		});
 
 		$('#post-status-select').siblings('a.edit-post-status').click(function() {
-			if ($('#post-status-select').is(":hidden")) {
+			if ( $( '#post-status-select' ).is( ':hidden' ) ) {
 				$('#post-status-select').slideDown('fast');
 				$(this).hide();
 			}
@@ -682,7 +691,15 @@ jQuery(document).ready( function($) {
 	// permalink
 	if ( $('#edit-slug-box').length ) {
 		editPermalink = function(post_id) {
-			var i, c = 0, e = $('#editable-post-name'), revert_e = e.html(), real_slug = $('#post_name'), revert_slug = real_slug.val(), b = $('#edit-slug-buttons'), revert_b = b.html(), full = $('#editable-post-name-full').html();
+			var slug_value, i,
+				c = 0,
+				e = $( '#editable-post-name' ),
+				revert_e = e.html(),
+				real_slug = $( '#post_name' ),
+				revert_slug = real_slug.val(),
+				b = $( '#edit-slug-buttons' ),
+				revert_b = b.html(),
+				full = $( '#editable-post-name-full' ).html();
 
 			$('#view-post-btn').hide();
 			b.html('<a href="#" class="save button button-small">'+postL10n.ok+'</a> <a class="cancel" href="#">'+postL10n.cancel+'</a>');
@@ -738,16 +755,16 @@ jQuery(document).ready( function($) {
 					b.children('.cancel').click();
 					return false;
 				}
-			}).keyup(function(e) {
+			} ).keyup( function() {
 				real_slug.val(this.value);
 			}).focus();
-		}
+		};
 
 		makeSlugeditClickable = function() {
 			$('#editable-post-name').click(function() {
 				$('#edit-slug-buttons').children('.edit-slug').click();
 			});
-		}
+		};
 		makeSlugeditClickable();
 	}
 
@@ -774,7 +791,7 @@ jQuery(document).ready( function($) {
 
 		var title = $('#' + id), titleprompt = $('#' + id + '-prompt-text');
 
-		if ( title.val() == '' )
+		if ( '' === title.val() )
 			titleprompt.removeClass('screen-reader-text');
 
 		titleprompt.click(function(){
@@ -783,7 +800,7 @@ jQuery(document).ready( function($) {
 		});
 
 		title.blur(function(){
-			if ( this.value == '' )
+			if ( '' === this.value )
 				titleprompt.removeClass('screen-reader-text');
 		}).focus(function(){
 			titleprompt.addClass('screen-reader-text');
@@ -791,7 +808,7 @@ jQuery(document).ready( function($) {
 			titleprompt.addClass('screen-reader-text');
 			$(this).unbind(e);
 		});
-	}
+	};
 
 	wptitlehint();
 
@@ -807,7 +824,7 @@ jQuery(document).ready( function($) {
 			return false;
 		}
 
-		function endDrag(e) {
+		function endDrag() {
 			var height;
 
 			textarea.focus();
@@ -854,7 +871,7 @@ jQuery(document).ready( function($) {
 			}
 
 			// resize TinyMCE to match the textarea height when switching Text -> Visual
-			ed.onLoadContent.add( function(ed, o) {
+			ed.onLoadContent.add( function() {
 				var ifr_height, node = document.getElementById('content'),
 					height = node ? parseInt( node.style.height, 10 ) : 0,
 					tb_height = $('#content_tbl tr.mceFirst').height() || 33;
@@ -877,7 +894,7 @@ jQuery(document).ready( function($) {
 			});
 
 			// resize the textarea to match TinyMCE's height when switching Visual -> Text
-			ed.onSaveContent.add( function(ed, o) {
+			ed.onSaveContent.add( function() {
 				var height = getHeight();
 
 				if ( !height || height < 50 || height > 5000 )
@@ -888,8 +905,8 @@ jQuery(document).ready( function($) {
 
 			// save on resizing TinyMCE
 			ed.onPostRender.add(function() {
-				$('#content_resize').on('mousedown.wp-mce-resize', function(e){
-					$(document).on('mouseup.wp-mce-resize', function(e){
+				$( '#content_resize' ).on( 'mousedown.wp-mce-resize', function() {
+					$( document ).on( 'mouseup.wp-mce-resize', function() {
 						var height;
 
 						$(document).off('mouseup.wp-mce-resize');
@@ -904,7 +921,7 @@ jQuery(document).ready( function($) {
 		});
 
 		// When changing post formats, change the editor body class
-		$('#post-formats-select input.post-format').on( 'change.set-editor-class', function( event ) {
+		$( '#post-formats-select input.post-format' ).on( 'change.set-editor-class', function() {
 			var editor, body, format = this.id;
 
 			if ( format && $( this ).prop('checked') ) {
